@@ -23,3 +23,15 @@ class TestCountriesObject(TestCase):
     def test_countries_custom_added_len(self):
         with self.settings(COUNTRIES_OVERRIDE={'XX': 'Neverland'}):
             self.assertEqual(len(countries), self.EXPECTED_COUNTRY_COUNT + 1)
+
+    def test_countries_custom_ugettext_evaluation(self):
+
+        class FakeLazyUGetText(object):
+
+            def __bool__(self):
+                raise ValueError("Can't evaluate lazy_ugettext yet")
+
+            __nonzero__ = __bool__
+
+        with self.settings(COUNTRIES_OVERRIDE={'AU': FakeLazyUGetText()}):
+            countries.countries
